@@ -6,6 +6,8 @@ import shutil
 
 from gettext import gettext as _
 
+from asgiref.sync import sync_to_async
+
 from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
@@ -29,12 +31,14 @@ from pulpcore.plugin.stages import (
     RemoteArtifactSaver,
     Stage,
 )
+from pulpcore.plugin.sync import sync_to_async_iterable
 
 from pulp_2to3_migration.app.constants import (
     DEFAULT_BATCH_SIZE,
     NOT_USED,
 )
 from pulp_2to3_migration.app.models import (
+    Pulp2Content,
     Pulp2Importer,
     Pulp2LazyCatalog,
 )
@@ -235,7 +239,7 @@ class ContentMigrationFirstStage(Stage):
         async with ProgressReport(
             message='Migrating {} content to Pulp 3'.format(content_type),
             code='migrating.{}.content'.format(self.migrator.pulp2_plugin),
-            total=pulp_2to3_detail_qs.count()
+            total=await sync_to_async(pulp_2to3_detail_qs.count)()
         ) as pb:
             select_extra = [
                 'pulp2content',
@@ -246,9 +250,14 @@ class ContentMigrationFirstStage(Stage):
                 select_extra.append('pulp2content__pulp2_repo')
 
             pulp_2to3_detail_qs = pulp_2to3_detail_qs.select_related(*select_extra)
-            for pulp_2to3_detail_content in pulp_2to3_detail_qs.iterator(chunk_size=800):
+            async for pulp_2to3_detail_content in sync_to_async_iterable(
+                    pulp_2to3_detail_qs.iterator(chunk_size=800)
+            ):
                 dc = None
-                pulp2content = pulp_2to3_detail_content.pulp2content
+                pulp2content = await sync_to_async(Pulp2Content.objects.get)(
+                    pk=pulp_2to3_detail_content.pulp2content.pk
+                )
+
                 # only content that supports on_demand download can have entries in LCE
                 if is_lazy_type:
                     # get all Lazy Catalog Entries (LCEs) for this content
@@ -256,6 +265,7 @@ class ContentMigrationFirstStage(Stage):
                         pulp2_unit_id=pulp2content.pulp2_id,
                         is_migrated=False,
                     )
+                    await sync_to_async(bool)(pulp2lazycatalog)  # force queryset to evaluate
 
                     if not pulp2content.downloaded and not pulp2lazycatalog:
                         # A distribution tree can be from an on_demand repo but without any images,
@@ -284,7 +294,9 @@ class ContentMigrationFirstStage(Stage):
                             continue
                 else:
                     # create pulp3 content and assign relations if present
-                    pulp3content, extra_info = pulp_2to3_detail_content.create_pulp3_content()
+                    pulp3content, extra_info = await sync_to_async(
+                        pulp_2to3_detail_content.create_pulp3_content
+                    )()
 
                 # If we can't find/create the Distribution, warn and skip
                 if pulp3content is None:
@@ -305,8 +317,10 @@ class ContentMigrationFirstStage(Stage):
                     base_path = pulp2content.pulp2_storage_path
                     remotes = set()
                     missing_artifact = False
+                    remote_declarative_artifacts = []
 
                     for image_relative_path in extra_info['download']['images']:
+                        remote_url_tuples = []
                         image_path = os.path.join(base_path, image_relative_path)
                         downloaded = os.path.exists(image_path)
                         if downloaded:
@@ -319,31 +333,39 @@ class ContentMigrationFirstStage(Stage):
                         else:
                             artifact = Artifact()
 
-                        lces = pulp2lazycatalog.filter(pulp2_storage_path=image_path)
-                        if lces:
-                            remote_declarative_artifacts = []
+                        lces = await sync_to_async(list)(
+                            pulp2lazycatalog.filter(pulp2_storage_path=image_path)
+                        )
 
-                            for lce in lces:
-                                remote = get_remote_by_importer_id(lce.pulp2_importer_id)
-
-                                if not remote and not downloaded:
-                                    continue
+                        if not lces and not downloaded:
+                            continue
 
+                        # collect all urls and respective migrated remotes for the image
+                        for lce in lces:
+                            remote = await sync_to_async(get_remote_by_importer_id)(
+                                lce.pulp2_importer_id
+                            )
+                            if remote:
                                 remotes.add(remote)
-                                da = DeclarativeArtifact(
-                                    artifact=artifact,
-                                    url=lce.pulp2_url,
-                                    relative_path=image_relative_path,
-                                    remote=remote,
-                                    deferred_download=not downloaded)
-                                remote_declarative_artifacts.append(da)
+                                remote_url_tuples.append((remote, lce.pulp2_url))
 
-                            if not remote_declarative_artifacts:
+                        for remote, url in remote_url_tuples:
+                            da = DeclarativeArtifact(
+                                artifact=artifact,
+                                url=lce.pulp2_url,
+                                relative_path=image_relative_path,
+                                remote=remote,
+                                deferred_download=not downloaded)
+                            remote_declarative_artifacts.append(da)
+
+                        if not remote_url_tuples:
+                            # either no LCEs existed but it's a downloaded content (and we can
+                            # proceed), or remotes for any of LCEs haven't been migrated (and
+                            # nothing can be done at this point)
+                            if not downloaded:
                                 missing_artifact = True
                                 break
 
-                            d_artifacts.extend(remote_declarative_artifacts)
-                        else:
                             da = DeclarativeArtifact(
                                 artifact=artifact,
                                 url=NOT_USED,
@@ -352,6 +374,8 @@ class ContentMigrationFirstStage(Stage):
                                 deferred_download=False)
                             d_artifacts.append(da)
 
+                        d_artifacts.extend(remote_declarative_artifacts)
+
                     # Only skip the rest of the steps if there are any images that are expected
                     # to be downloaded. There are distribution trees without images in the wild,
                     # e.g. CentOS 8 High Availability.
@@ -416,23 +440,29 @@ class ContentMigrationFirstStage(Stage):
                             await pb.aincrement()
                         continue
 
+                    relative_path = (
+                        pulp_2to3_detail_content.relative_path_for_content_artifact
+                    )
+                    remote_lce_tuples = []
+                    deferred_download = not pulp2content.downloaded
+
                     if is_lazy_type and pulp2lazycatalog:
+                        for lce in pulp2lazycatalog:
+                            remote = await sync_to_async(get_remote_by_importer_id)(
+                                lce.pulp2_importer_id
+                            )
+                            if remote:
+                                remote_lce_tuples.append((remote, lce))
+
                         # handle DA and RA creation for content that supports on_demand
                         # Downloaded or on_demand content with LCEs.
                         #
                         # To create multiple remote artifacts, create multiple instances of
                         # declarative content which will differ by url/remote in their
                         # declarative artifacts
-                        at_least_one_lce_migrated = False
-                        for lce in pulp2lazycatalog:
-                            remote = get_remote_by_importer_id(lce.pulp2_importer_id)
-                            deferred_download = not pulp2content.downloaded
-                            if not remote and deferred_download:
-                                continue
 
-                            relative_path = (
-                                pulp_2to3_detail_content.relative_path_for_content_artifact
-                            )
+                    if remote_lce_tuples:
+                        for remote, lce in remote_lce_tuples:
                             da = DeclarativeArtifact(
                                 artifact=artifact,
                                 url=lce.pulp2_url,
@@ -440,22 +470,27 @@ class ContentMigrationFirstStage(Stage):
                                 remote=remote,
                                 deferred_download=deferred_download)
                             lce.is_migrated = True
-                            at_least_one_lce_migrated = True
                             dc = DeclarativeContent(content=pulp3content, d_artifacts=[da])
+
+                            # yes, all LCEs are assigned for each dc to be resolved at a later
+                            # stage. Some LCEs might be "bad" and not have a migrated importer
+                            # but we still need to resolved such. It creates some duplicated LCEs
+                            # to process later but ensures that all are resolved if at least one
+                            # valid one is migrated.
+                            future_relations.update({'lces': list(pulp2lazycatalog)})
                             dc.extra_data = future_relations
                             await self.put(dc)
 
-                        if not at_least_one_lce_migrated:
+                    else:
+                        # No migratable LCE available
+                        if deferred_download:
                             _logger.warn(
                                 _('On_demand content cannot be migrated without a remote '
                                   'pulp2 unit_id: {}'.format(pulp2content.pulp2_id)
                                   )
                             )
-                        future_relations.update({'lces': list(pulp2lazycatalog)})
-                    else:
-                        relative_path = (
-                            pulp_2to3_detail_content.relative_path_for_content_artifact
-                        )
+                            continue
+
                         da = DeclarativeArtifact(
                             artifact=artifact,
                             url=NOT_USED,
@@ -493,17 +528,19 @@ class UpdateLCEs(Stage):
         Find LCEs in the extra_data and flip the is_migrated flag to True
         """
         async for batch in self.batches():
-            pulp2lces_batch = []
-            with transaction.atomic():
-                for d_content in batch:
-                    lces = d_content.extra_data.get('lces')
-                    if lces:
-                        pulp2lces_batch.extend(lces)
+            def process_batch():
+                pulp2lces_batch = []
+                with transaction.atomic():
+                    for d_content in batch:
+                        lces = d_content.extra_data.get('lces')
+                        if lces:
+                            pulp2lces_batch.extend(lces)
 
-                Pulp2LazyCatalog.objects.bulk_update(objs=pulp2lces_batch,
-                                                     fields=['is_migrated'],
-                                                     batch_size=DEFAULT_BATCH_SIZE)
+                    Pulp2LazyCatalog.objects.bulk_update(objs=pulp2lces_batch,
+                                                         fields=['is_migrated'],
+                                                         batch_size=DEFAULT_BATCH_SIZE)
 
+            await sync_to_async(process_batch)()
             for d_content in batch:
                 await self.put(d_content)
 
@@ -523,16 +560,17 @@ class RelatePulp2to3Content(Stage):
         of a declarative Pulp 3 content.
         """
         async for batch in self.batches():
-            pulp2content_batch = []
-            with transaction.atomic():
-                for d_content in batch:
-                    pulp2content = d_content.extra_data.get('pulp2content')
-                    pulp2content.pulp3_content = d_content.content.master
-                    pulp2content_batch.append(pulp2content)
-
-                pulp2content.__class__.objects.bulk_update(objs=pulp2content_batch,
-                                                           fields=['pulp3_content'],
-                                                           batch_size=DEFAULT_BATCH_SIZE)
+            def process_batch():
+                pulp2content_batch = []
+                with transaction.atomic():
+                    for d_content in batch:
+                        pulp2content = d_content.extra_data.get('pulp2content')
+                        pulp2content.pulp3_content = d_content.content.master
+                        pulp2content_batch.append(pulp2content)
 
+                    pulp2content.__class__.objects.bulk_update(objs=pulp2content_batch,
+                                                               fields=['pulp3_content'],
+                                                               batch_size=DEFAULT_BATCH_SIZE)
+            await sync_to_async(process_batch)()
             for d_content in batch:
                 await self.put(d_content)
