@@ -11,6 +11,8 @@ from pulp_rpm.app.models import (
 )
 from pulp_rpm.app.tasks.publishing import publish
 
+from urllib.parse import urlparse, urlunparse
+
 
 class RpmImporter(Pulp2to3Importer):
     """
@@ -35,6 +37,11 @@ class RpmImporter(Pulp2to3Importer):
         sles_auth_token = pulp2_config.get('query_auth_token')
         if sles_auth_token:
             base_config['sles_auth_token'] = sles_auth_token
+        else:
+            url = urlparse(pulp2_config.get('feed', ''))
+            if url.query and '=' not in url.query and '&' not in url.query:
+                base_config['sles_auth_token'] = url.query
+                base_config['url'] = urlunparse(url._replace(query=''))
         return RpmRemote.objects.update_or_create(name=name, defaults=base_config)
 
 
@@ -46,7 +53,7 @@ class RpmDistributor(Pulp2to3Distributor):
     pulp3_distribution_models = [RpmDistribution]
 
     @classmethod
-    def migrate_to_pulp3(cls, pulp2distributor, repo_version):
+    def migrate_to_pulp3(cls, pulp2distributor, repo_version, signing_service):
         """
         Migrate distributor to Pulp 3.
 
@@ -66,7 +73,7 @@ class RpmDistributor(Pulp2to3Distributor):
         if not repo_version:
             repo = pulp2distributor.pulp2_repos.filter(not_in_plan=False, is_migrated=True)
             repo_version = repo[0].pulp3_repository_version
-        publication = repo_version.publication_set.first()
+        publication = repo_version.publication_set.filter(complete=True).first()
         if not publication:
             pulp2_checksum_type = pulp2_config.get('checksum_type')
             checksum_types = None
@@ -92,7 +99,7 @@ class RpmDistributor(Pulp2to3Distributor):
             except TypeError:
                 # hack, pulp_rpm <3.9 doesn't support sqlite_metadata kwarg
                 publish(repo_version.pk, checksum_types=checksum_types)
-            publication = repo_version.publication_set.first()
+            publication = repo_version.publication_set.filter(complete=True).first()
 
         # create distribution
         distribution_data = cls.parse_base_config(pulp2distributor, pulp2_config)
