@@ -1,8 +1,8 @@
 PULP2_MONGODB = {
     'name': 'pulp_database',
-    'seeds': '172.17.0.1:27017',
-    'username': 'ci_cd',
-    'password': 'ci_cd',
+    'seeds': 'localhost:27017',
+    'username': '',
+    'password': '',
     'replica_set': '',
     'ssl': False,
     'ssl_keyfile': '',
@@ -12,3 +12,5 @@ PULP2_MONGODB = {
 }
 
 ALLOWED_CONTENT_CHECKSUMS = ['md5', 'sha1', 'sha224', 'sha256', 'sha384', 'sha512']
+
+CONTENT_PREMIGRATION_BATCH_SIZE = 1000
